==> smartclientcore7.5.6.zip: docs/constants/interfaces/README.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / constants/interfaces

# constants/interfaces

## Index

### Interfaces

- [ActiveAdReinsertion](constants/interfaces/interfaces/ActiveAdReinsertion.md)
- [AdBreakSetup](constants/interfaces/interfaces/AdBreakSetup.md)
- [AdCreative](constants/interfaces/interfaces/AdCreative.md)
- [AdDisplayTime](constants/interfaces/interfaces/AdDisplayTime.md)
- [AdEvent](constants/interfaces/interfaces/AdEvent.md)
- [AdPlaylistSetup](constants/interfaces/interfaces/AdPlaylistSetup.md)
- [AdPlaylistSetupExtended](constants/interfaces/interfaces/AdPlaylistSetupExtended.md)
- [AdReinsertionHomad](constants/interfaces/interfaces/AdReinsertionHomad.md)
- [AdReinsertionHomadUtils](constants/interfaces/interfaces/AdReinsertionHomadUtils.md)
- [AdRequestMethod](constants/interfaces/interfaces/AdRequestMethod.md)
- [AdSlotAdReinsertionConfig](constants/interfaces/interfaces/AdSlotAdReinsertionConfig.md)
- [AdSlotSetup](constants/interfaces/interfaces/AdSlotSetup.md)
- [AdVerification](constants/interfaces/interfaces/AdVerification.md)
- [AdVerificationSetup](constants/interfaces/interfaces/AdVerificationSetup.md)
- [BaseCreative](constants/interfaces/interfaces/BaseCreative.md)
- [ClosedCaption](constants/interfaces/interfaces/ClosedCaption.md)
- [CompanionAdCreative](constants/interfaces/interfaces/CompanionAdCreative.md)
- [CoreConfig](constants/interfaces/interfaces/CoreConfig.md)
- [CreativeIds](constants/interfaces/interfaces/CreativeIds.md)
- [CreativeVariation](constants/interfaces/interfaces/CreativeVariation.md)
- [CreativeViewTracker](constants/interfaces/interfaces/CreativeViewTracker.md)
- [CurrentContentSource](constants/interfaces/interfaces/CurrentContentSource.md)
- [Debugger](constants/interfaces/interfaces/Debugger.md)
- [DefaultMimeTypes](constants/interfaces/interfaces/DefaultMimeTypes.md)
- [DeliverAd](constants/interfaces/interfaces/DeliverAd.md)
- [ElementSize](constants/interfaces/interfaces/ElementSize.md)
- [EnvironmentVars](constants/interfaces/interfaces/EnvironmentVars.md)
- [ErrorAdReinsertion](constants/interfaces/interfaces/ErrorAdReinsertion.md)
- [ErrorStatus](constants/interfaces/interfaces/ErrorStatus.md)
- [ErrorXHR](constants/interfaces/interfaces/ErrorXHR.md)
- [EventCallback](constants/interfaces/interfaces/EventCallback.md)
- [EventHandler](constants/interfaces/interfaces/EventHandler.md)
- [ExtendedEnvironmentVars](constants/interfaces/interfaces/ExtendedEnvironmentVars.md)
- [Extension](constants/interfaces/interfaces/Extension.md)
- [FacadeBase](constants/interfaces/interfaces/FacadeBase.md)
- [IconProgram](constants/interfaces/interfaces/IconProgram.md)
- [IncomingMessage](constants/interfaces/interfaces/IncomingMessage.md)
- [InteractiveCreative](constants/interfaces/interfaces/InteractiveCreative.md)
- [MediaErrorStatus](constants/interfaces/interfaces/MediaErrorStatus.md)
- [MediaFile](constants/interfaces/interfaces/MediaFile.md)
- [NonLinearAdCreative](constants/interfaces/interfaces/NonLinearAdCreative.md)
- [NonLinearVariation](constants/interfaces/interfaces/NonLinearVariation.md)
- [ParserConfig](constants/interfaces/interfaces/ParserConfig.md)
- [PlayerDimension](constants/interfaces/interfaces/PlayerDimension.md)
- [PlayerEventMap](constants/interfaces/interfaces/PlayerEventMap.md)
- [PlayerFacade](constants/interfaces/interfaces/PlayerFacade.md)
- [PublicAdAPI](constants/interfaces/interfaces/PublicAdAPI.md)
- [PublicAdSlotAPI](constants/interfaces/interfaces/PublicAdSlotAPI.md)
- [Rect](constants/interfaces/interfaces/Rect.md)
- [Resource](constants/interfaces/interfaces/Resource.md)
- [SeparationClipCreative](constants/interfaces/interfaces/SeparationClipCreative.md)
- [SeparationClips](constants/interfaces/interfaces/SeparationClips.md)
- [SequenceData](constants/interfaces/interfaces/SequenceData.md)
- [StreamingCreative](constants/interfaces/interfaces/StreamingCreative.md)
- [Timeouts](constants/interfaces/interfaces/Timeouts.md)
- [Tracker](constants/interfaces/interfaces/Tracker.md)
- [URLConfig](constants/interfaces/interfaces/URLConfig.md)
- [UniversalAdId](constants/interfaces/interfaces/UniversalAdId.md)
- [VMAPAdReinsertionConfig](constants/interfaces/interfaces/VMAPAdReinsertionConfig.md)
- [VPAIDCreative](constants/interfaces/interfaces/VPAIDCreative.md)
- [Viewability](constants/interfaces/interfaces/Viewability.md)
- [Wrapper](constants/interfaces/interfaces/Wrapper.md)

==> smartclientcore7.6.0-dev.zip: docs/constants/interfaces/README.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / constants/interfaces

# constants/interfaces

## Index

### Interfaces

- [ActiveAdReinsertion](constants/interfaces/interfaces/ActiveAdReinsertion.md)
- [AdBreakSetup](constants/interfaces/interfaces/AdBreakSetup.md)
- [AdCreative](constants/interfaces/interfaces/AdCreative.md)
- [AdDisplayTime](constants/interfaces/interfaces/AdDisplayTime.md)
- [AdEvent](constants/interfaces/interfaces/AdEvent.md)
- [AdPlaylistSetup](constants/interfaces/interfaces/AdPlaylistSetup.md)
- [AdPlaylistSetupExtended](constants/interfaces/interfaces/AdPlaylistSetupExtended.md)
- [AdReinsertionHomad](constants/interfaces/interfaces/AdReinsertionHomad.md)
- [AdReinsertionHomadUtils](constants/interfaces/interfaces/AdReinsertionHomadUtils.md)
- [AdRequestMethod](constants/interfaces/interfaces/AdRequestMethod.md)
- [AdSlotAdReinsertionConfig](constants/interfaces/interfaces/AdSlotAdReinsertionConfig.md)
- [AdSlotSetup](constants/interfaces/interfaces/AdSlotSetup.md)
- [AdVerification](constants/interfaces/interfaces/AdVerification.md)
- [AdVerificationSetup](constants/interfaces/interfaces/AdVerificationSetup.md)
- [BaseCreative](constants/interfaces/interfaces/BaseCreative.md)
- [ClickTracker](constants/interfaces/interfaces/ClickTracker.md)
- [ClosedCaption](constants/interfaces/interfaces/ClosedCaption.md)
- [CompanionAdCreative](constants/interfaces/interfaces/CompanionAdCreative.md)
- [CoreConfig](constants/interfaces/interfaces/CoreConfig.md)
- [CreativeIds](constants/interfaces/interfaces/CreativeIds.md)
- [CreativeVariation](constants/interfaces/interfaces/CreativeVariation.md)
- [CreativeViewTracker](constants/interfaces/interfaces/CreativeViewTracker.md)
- [CurrentContentSource](constants/interfaces/interfaces/CurrentContentSource.md)
- [Debugger](constants/interfaces/interfaces/Debugger.md)
- [DefaultMimeTypes](constants/interfaces/interfaces/DefaultMimeTypes.md)
- [DeliverAd](constants/interfaces/interfaces/DeliverAd.md)
- [ElementSize](constants/interfaces/interfaces/ElementSize.md)
- [EnvironmentVars](constants/interfaces/interfaces/EnvironmentVars.md)
- [ErrorAdReinsertion](constants/interfaces/interfaces/ErrorAdReinsertion.md)
- [ErrorStatus](constants/interfaces/interfaces/ErrorStatus.md)
- [ErrorXHR](constants/interfaces/interfaces/ErrorXHR.md)
- [EventCallback](constants/interfaces/interfaces/EventCallback.md)
- [EventHandler](constants/interfaces/interfaces/EventHandler.md)
- [ExtendedEnvironmentVars](constants/interfaces/interfaces/ExtendedEnvironmentVars.md)
- [Extension](constants/interfaces/interfaces/Extension.md)
- [FacadeBase](constants/interfaces/interfaces/FacadeBase.md)
- [IconProgram](constants/interfaces/interfaces/IconProgram.md)
- [IncomingMessage](constants/interfaces/interfaces/IncomingMessage.md)
- [InteractiveAdCreative](constants/interfaces/interfaces/InteractiveAdCreative.md)
- [MediaErrorStatus](constants/interfaces/interfaces/MediaErrorStatus.md)
- [MediaFile](constants/interfaces/interfaces/MediaFile.md)
- [NonLinearAdCreative](constants/interfaces/interfaces/NonLinearAdCreative.md)
- [NonLinearVariation](constants/interfaces/interfaces/NonLinearVariation.md)
- [ParsedData](constants/interfaces/interfaces/ParsedData.md)
- [ParserConfig](constants/interfaces/interfaces/ParserConfig.md)
- [PlayerDimension](constants/interfaces/interfaces/PlayerDimension.md)
- [PlayerEventMap](constants/interfaces/interfaces/PlayerEventMap.md)
- [PlayerFacade](constants/interfaces/interfaces/PlayerFacade.md)
- [PublicAdAPI](constants/interfaces/interfaces/PublicAdAPI.md)
- [PublicAdSlotAPI](constants/interfaces/interfaces/PublicAdSlotAPI.md)
- [Rect](constants/interfaces/interfaces/Rect.md)
- [Resource](constants/interfaces/interfaces/Resource.md)
- [RuntimeCreative](constants/interfaces/interfaces/RuntimeCreative.md)
- [SeparationClipCreative](constants/interfaces/interfaces/SeparationClipCreative.md)
- [SeparationClips](constants/interfaces/interfaces/SeparationClips.md)
- [SequenceData](constants/interfaces/interfaces/SequenceData.md)
- [StreamingAdCreative](constants/interfaces/interfaces/StreamingAdCreative.md)
- [Timeouts](constants/interfaces/interfaces/Timeouts.md)
- [Tracker](constants/interfaces/interfaces/Tracker.md)
- [TrackingEvents](constants/interfaces/interfaces/TrackingEvents.md)
- [URLConfig](constants/interfaces/interfaces/URLConfig.md)
- [UniversalAdId](constants/interfaces/interfaces/UniversalAdId.md)
- [VMAPAdReinsertionConfig](constants/interfaces/interfaces/VMAPAdReinsertionConfig.md)
- [VPAIDCreative](constants/interfaces/interfaces/VPAIDCreative.md)
- [Viewability](constants/interfaces/interfaces/Viewability.md)
- [Wrapper](constants/interfaces/interfaces/Wrapper.md)
